{{ '#' * (len(modname)+1) }}
{{ modname }}
{{ '#' * (len(modname)+1) }}

.. start short_desc
.. end short_desc


.. start shields
.. end shields

Installation
--------------

.. start installation
.. end installation
